orion.primitives.timeseries\_anomalies.find\_anomalies
======================================================

.. currentmodule:: orion.primitives.timeseries_anomalies

.. autofunction:: find_anomalies